@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-from __future__ import (absolute_import, division, print_function)
+from __future__ import absolute_import, division, print_function
 
 import numpy as np
 from ..util import interpolate_ahead, avg_stddev
@@ -11,11 +11,11 @@ def locate_discontinuity(grid, y, consider, trnsfm=lambda x: x, ntrail=2):
     tg = trnsfm(grid)
     dtg = np.diff(tg)
     err = np.zeros(y.size)
-    for d in ('fw', 'bw'):
+    for d in ("fw", "bw"):
         est, slc = interpolate_ahead(tg, y, ntrail, d)
-        start = (ntrail - 1) if d == 'fw' else 0
-        stop = -(ntrail - 1) if d == 'bw' else None
-        err[slc] += np.abs(y[slc] - est)/dtg[start:stop]*dy[start:stop]
+        start = (ntrail - 1) if d == "fw" else 0
+        stop = -(ntrail - 1) if d == "bw" else None
+        err[slc] += np.abs(y[slc] - est) / dtg[start:stop] * dy[start:stop]
     imax = np.argsort(err)[-consider:][::-1]
     return [(tg[m], err[m]) for m in imax]
 
@@ -27,7 +27,7 @@ def pool_discontinuity_approx(loc_res, consistency_criterion=10):
 
 
 def grid_error(grid, y, ntrail=2):
-    """ Estimates error at each grid point from extrapolation.
+    """Estimates error at each grid point from extrapolation.
 
     Extrapolates from left ('fw') or from right ('bw').
 
@@ -39,5 +39,5 @@ def grid_error(grid, y, ntrail=2):
         Number of points to include in the look-ahead extrapolation.
 
     """
-    est, _ = interpolate_ahead(grid, y, ntrail, direction='both')
+    est, _ = interpolate_ahead(grid, y, ntrail, direction="both")
     return est - y
